# BrazilClimateFinance
This package provides functions to clean raw databases, filter climate alignment investments, and build the final normalized dataset.

# To install package:
```bash
pip install BrazilClimateFinance
```

asd